@@ -307,11 +307,14 @@ globus_l_gfs_signal_init()
         NULL);
 #   endif
 #   ifdef SIGHUP
-    globus_callback_register_signal_handler(
-        SIGHUP,
-        GLOBUS_TRUE,
-        globus_l_gfs_sighup,
-        NULL);
+    if(globus_i_gfs_config_string("loaded_config"))
+    {
+        globus_callback_register_signal_handler(
+            SIGHUP,
+            GLOBUS_TRUE,
+            globus_l_gfs_sighup,
+            NULL);
+    }
 #   endif
 
 #   ifdef SIGKILL
@@ -604,7 +607,7 @@ globus_l_gfs_new_server_cb(
         {
             globus_gfs_log_message(
                 GLOBUS_GFS_LOG_INFO,
-             "Couldnt get remote contact.  Possible using a non-tcp protocol");
+                "Couldn't get remote contact.  Possibly using a non-tcp protocol.\n");
             remote_contact = strdup("0.0.0.0");
         }
         if(!globus_i_gfs_config_allow_addr(remote_contact, GLOBUS_FALSE))
@@ -625,7 +628,7 @@ globus_l_gfs_new_server_cb(
         {
             globus_gfs_log_message(
                 GLOBUS_GFS_LOG_INFO,
-             "Couldnt get remote contact.  Possible using a non-tcp protocol");
+                "Couldn't get remote contact.  Possibly using a non-tcp protocol.\n");
             remote_contact = strdup("0.0.0.0");
         }
         
@@ -648,7 +651,7 @@ globus_l_gfs_new_server_cb(
         {
             globus_gfs_log_message(
                 GLOBUS_GFS_LOG_INFO,
-             "Couldnt get local contact.  Possible using a non-tcp protocol");
+                "Couldn't get local contact.  Possibly using a non-tcp protocol.\n");
             local_contact = strdup("0.0.0.0");
         }
 
@@ -663,14 +666,26 @@ globus_l_gfs_new_server_cb(
             {
                 globus_gfs_log_message(
                     GLOBUS_GFS_LOG_INFO,
-                 "Couldnt get local contact.  Possible using a non-tcp protocol");
+                    "Couldn't get local contact.  Possibly using a non-tcp protocol.\n");
                 tmp_local_contact = strdup("0.0.0.0:0");
             }
 
             globus_gfs_config_set_ptr("contact_string", tmp_local_contact);
         }
 
-
+        result = globus_xio_handle_cntl(
+            handle,
+            globus_l_gfs_tcp_driver,
+            GLOBUS_XIO_TCP_SET_NODELAY,
+            GLOBUS_TRUE);
+        if(result != GLOBUS_SUCCESS)
+        {
+            globus_gfs_log_message(
+                GLOBUS_GFS_LOG_INFO, 
+                "Couldn't enable TCP_NODELAY.  Possibly using a non-tcp protocol.\n");
+            result = GLOBUS_SUCCESS;
+        }
+            
         result = globus_xio_handle_cntl(
             handle,
             globus_l_gfs_tcp_driver,
@@ -1482,7 +1497,10 @@ main(
             "Error: unable to drop supplemental group privileges.\n");
         return 1;
     }
-    setenv("GLOBUS_CALLBACK_POLLING_THREADS", "1", 1); 
+    if(!getenv("GLOBUS_CALLBACK_POLLING_THREADS"))
+    {
+        setenv("GLOBUS_CALLBACK_POLLING_THREADS", "1", 1); 
+    }
     /* activte globus stuff */    
     if((rc = globus_module_activate(GLOBUS_COMMON_MODULE)) != GLOBUS_SUCCESS ||
         (rc = globus_module_activate(GLOBUS_XIO_MODULE)) != GLOBUS_SUCCESS ||
